Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HTTPServer ¶
type HTTPServer struct {
// contains filtered or unexported fields
}
func (*HTTPServer) Close ¶
func (srv *HTTPServer) Close() error
Close stops listening and deinitializes HTTP server
type HTTPStatusError ¶
HTTPStatusError allows to return errors which can be converted to proper HTTP status codes.
type JSONErrorStruct ¶
JSONErrorStruct is a struct to be marshaled to JSON and reporting to the HTTP client.
Click to show internal directories.
Click to hide internal directories.